@@ -408,7 +408,7 @@ inline float fgamma(float f1){ return tgammaf(f1); }
 #if defined(__MINGW_H) || defined(VISUALC) // FIXME gamma, not used
 inline float fgamma(float f1){ return f1; }
 #else
-inline float fgamma(float f1){ return gammaf(f1); }
+inline float fgamma(float f1){ return gammaf(f1); } // or tgammaf(f1) on some versions of emscripten
 #endif
 #endif
 inline float atan2f(float f1,float f2,int rad){ if (rad) return atan2f(f1,f2); else return atan2f(f1,f2)*180/M_PI;}
